***************
Creating Arrays
***************

There are several ways to initialize arkouda ``pdarray`` objects, most of which come from NumPy.

Constant
========

.. autofunction:: arkouda.zeros

.. autofunction:: arkouda.ones

.. autofunction:: arkouda.zeros_like

.. autofunction:: arkouda.ones_like


Regular
=======

.. autofunction:: arkouda.arange

.. autofunction:: arkouda.linspace

Random
======

.. autofunction:: arkouda.randint

Concatenation
=============

.. autofunction:: arkouda.concatenate
